@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AbstractImporter_H
-#define AbstractImporter_H
+#pragma once
 #include "libimportwizard_export.h"
 #include <MailCommon/FilterImporterExporter>
 #include <QVector>
@@ -33,7 +32,7 @@ public:
     Q_DECLARE_FLAGS(TypeSupportedOptions, TypeSupportedOption)
 
     explicit AbstractImporter(QObject *parent);
-    virtual ~AbstractImporter();
+    ~AbstractImporter() override;
 
     /**
      * Return true if mail found on system
@@ -73,4 +72,3 @@ protected:
 };
 }
 
-#endif /* AbstractImporter_H */
